<?php

declare(strict_types=1);

namespace Drupal\fire_chaser\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\fire_chaser\Service\ModuleListService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for Fire Chaser routes.
 */
class FireChaserController {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The module list service.
   *
   * @var \Drupal\fire_chaser\Service\ModuleListService
   */
  protected $moduleListService;

  /**
   * Constructs a new ApiController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\fire_chaser\Service\ModuleListService $moduleListService
   *   The module list service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RequestStack $request_stack, ModuleListService $moduleListService) {
    $this->configFactory = $config_factory;
    $this->requestStack = $request_stack;
    $this->moduleListService = $moduleListService;
  }

  /**
   * Creates an instance of the controller.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('request_stack'),
      $container->get('fire_chaser.module_list_service')
    );
  }

  /**
   * Builds the response.
   */
  public function handle(): JsonResponse {
    $php_version = phpversion();
    $modules = $this->moduleListService->listModules();
    $packages = $this->moduleListService->getComposerPackages();

    // Replace this with your actual data.
    $data = [
      'php_version' => $php_version,
      'packages' => $packages,
      'drupal_version' => \Drupal::VERSION,
    ];

    return new JsonResponse($data);
  }

  /**
   * {@inheritdoc}
   */
  public function access() {
    $config = $this->configFactory->get('fire_chaser.settings');
    $internalKey = $config->get('apikey');

    $request = $this->requestStack->getCurrentRequest();
    $content = $request->getContent();
    $data = json_decode($content, TRUE);
    $externalKey = $data['apiKey'] ?? NULL;

    if ($externalKey && $internalKey === $externalKey) {
      return AccessResult::allowed();
    }
    else {
      return AccessResult::forbidden();
    }
  }

}
