<?php

namespace Drupal\Tests\fire_chaser\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that main page loads with module enabled.
 *
 * @group fire_chaser
 */
class ApiEndPointTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['fire_chaser'];

  /**
   * Theme to enable.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with permission to administer site configuration.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    \Drupal::configFactory()->getEditable('fire_chaser.settings')
      ->set('apikey', 'apikey')
      ->save();
  }

  /**
   * Test the api page returns a 403.
   */
  public function testApiPageSuccess() {
    $url = Url::fromRoute('fire_chaser.api');
    $url->setOption('query', ['apikey' => 'apikey']);
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('drupal_version');
    $this->assertSession()->pageTextContains('php_version');
    $this->assertSession()->pageTextContains('packages');
  }

  /**
   * Test the api page returns a 403.
   */
  public function testApiPageError() {
    $url = Url::fromRoute('fire_chaser.api');
    $url->setOption('query', ['apikey' => 'nokey']);
    $this->drupalGet(Url::fromRoute('fire_chaser.api'));
    $this->assertSession()->statusCodeEquals(403);
  }

}
