<?php

namespace Drupal\Tests\fire_chaser\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Simple test to ensure that main page loads with module enabled.
 *
 * @group fire_chaser
 */
class BasicTest extends BrowserTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = ['fire_chaser'];

  /**
   * Theme to enable.
   *
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with permission to administer site configuration.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser(['administer fire chaser configuration']);
    $this->drupalLogin($this->adminUser);
  }

  /**
   * Tests the config form and ensure it saves correctly.
   */
  public function testStyleGuidePageFunctional() {
    $this->drupalGet(Url::fromRoute('fire_chaser.settings'));
    $this->assertSession()->statusCodeEquals(200);

    $apiKey = ['apikey' => 'toast'];
    $this->submitForm($apiKey, 'Save configuration');

    $config = \Drupal::config('fire_chaser.settings');
    $this->assertEquals('toast', $config->get('apikey'), 'The configuration value was saved correctly.');

    $url = Url::fromRoute('fire_chaser.api');
    $url->setOption('query', ['apikey' => 'toast']);
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(200);

    $url = Url::fromRoute('fire_chaser.api');
    $url->setOption('query', ['apikey' => 'toaster']);
    $this->drupalGet($url);
    $this->assertSession()->statusCodeEquals(403);
  }

}
